@@ -1125,22 +1125,48 @@ cache_query_cb (GObject	     *object,
 	}
 }
 
+static gboolean
+file_is_crawl_directory (TrackerMinerFS *fs,
+                         GFile          *file)
+{
+	GList *dirs;
+
+	/* Check whether file is a crawl directory itself */
+	dirs = fs->private->config_directories;
+
+	while (dirs) {
+		DirectoryData *data;
+
+		data = dirs->data;
+		dirs = dirs->next;
+
+		if (g_file_equal (data->file, file)) {
+			return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
 static void
 ensure_iri_cache (TrackerMinerFS *fs,
-                  GFile          *parent)
+                  GFile          *file)
 {
 	gchar *query, *uri;
 	CacheQueryData data;
+	GFile *parent;
 
 	g_hash_table_remove_all (fs->private->iri_cache);
 
+	parent = g_file_get_parent (file);
 	uri = g_file_get_uri (parent);
 
 	g_debug ("Generating IRI cache for folder: %s", uri);
 
-	query = g_strdup_printf ("SELECT ?uri ?u { "
-	                         "  ?u nie:url ?uri . "
-	                         "  FILTER (tracker:uri-is-parent (\"%s\", ?uri)) "
+	query = g_strdup_printf ("SELECT ?url ?u { "
+	                         "  ?u nfo:belongsToContainer ?p ; "
+	                         "     nie:url ?url . "
+	                         "  ?p nie:url \"%s\" "
 	                         "}",
 	                         uri);
 	g_free (uri);
@@ -1158,6 +1184,18 @@ ensure_iri_cache (TrackerMinerFS *fs,
 
 	g_main_loop_unref (data.main_loop);
 	g_hash_table_unref (data.values);
+
+	if (g_hash_table_size (data.values) == 0 &&
+	    file_is_crawl_directory (fs, file)) {
+		gchar *query_iri;
+
+		if (item_query_exists (fs, file, &query_iri, NULL)) {
+			g_hash_table_insert (data.values,
+			                     g_object_ref (file), query_iri);
+		}
+	}
+
+	g_object_unref (parent);
 	g_free (query);
 }
 
@@ -1345,7 +1383,7 @@ item_add_or_update (TrackerMinerFS *fs,
 				fs->private->current_parent_urn = NULL;
 			}
 
-			ensure_iri_cache (fs, parent);
+			ensure_iri_cache (fs, file);
 		}
 
 		parent_urn = fs->private->current_parent_urn;
@@ -2189,11 +2227,11 @@ ensure_mtime_cache (TrackerMinerFS *fs,
 
 	g_debug ("Generating mtime cache for folder: %s", uri);
 
-	query = g_strdup_printf ("SELECT ?uri nfo:fileLastModified (?u) { "
-	                         "  ?u nie:url ?uri . "
-	                         "  FILTER (tracker:uri-is-parent (\"%s\", ?uri)) "
-	                         "}",
-	                         uri);
+	query = g_strdup_printf ("SELECT ?url ?last { ?u nfo:belongsToContainer ?p ; "
+	                                                "nie:url ?url ; "
+	                                                "nfo:fileLastModified ?last . "
+	                                             "?p nie:url \"%s\" }", uri);
+
 	g_free (uri);
 
 	data.main_loop = g_main_loop_new (NULL, FALSE);
@@ -2204,12 +2242,37 @@ ensure_mtime_cache (TrackerMinerFS *fs,
 	                              NULL,
 	                              cache_query_cb,
 	                              &data);
+	g_free (query);
 
 	g_main_loop_run (data.main_loop);
 
+	if (g_hash_table_size (data.values) == 0 &&
+	    file_is_crawl_directory (fs, file)) {
+		/* File is a crawl directory itself, query its mtime directly */
+		uri = g_file_get_uri (file);
+
+		g_debug ("Folder %s is a crawl directory, generating mtime cache for it", uri);
+
+		query = g_strdup_printf ("SELECT ?url ?last "
+		                         "WHERE { "
+		                         "  ?u nfo:fileLastModified ?last ; "
+		                         "     nie:url ?url ; "
+		                         "     nie:url \"%s\" "
+		                         "}", uri);
+		g_free (uri);
+
+		tracker_miner_execute_sparql (TRACKER_MINER (fs),
+		                              query,
+		                              NULL,
+		                              cache_query_cb,
+		                              &data);
+		g_free (query);
+
+		g_main_loop_run (data.main_loop);
+	}
+
 	g_main_loop_unref (data.main_loop);
 	g_hash_table_unref (data.values);
-	g_free (query);
 }
 
 static gboolean
@@ -2705,7 +2768,7 @@ static gboolean
 crawl_directories_cb (gpointer user_data)
 {
 	TrackerMinerFS *fs = user_data;
-	gchar *path;
+	gchar *path, *path_utf8;
 	gchar *str;
 
 	if (fs->private->current_directory) {
@@ -2732,12 +2795,15 @@ crawl_directories_cb (gpointer user_data)
 	                                          fs->private->current_directory);
 
 	path = g_file_get_path (fs->private->current_directory->file);
+	path_utf8 = g_filename_to_utf8 (path, -1, NULL, NULL, NULL);
+	g_free (path);
 
 	if (fs->private->current_directory->recurse) {
-		str = g_strdup_printf ("Crawling recursively directory '%s'", path);
+		str = g_strdup_printf ("Crawling recursively directory '%s'", path_utf8);
 	} else {
-		str = g_strdup_printf ("Crawling single directory '%s'", path);
+		str = g_strdup_printf ("Crawling single directory '%s'", path_utf8);
 	}
+	g_free (path_utf8);
 
 	g_message ("%s", str);
 
@@ -2747,7 +2813,6 @@ crawl_directories_cb (gpointer user_data)
 	              "status", str,
 	              NULL);
 	g_free (str);
-	g_free (path);
 
 	if (tracker_crawler_start (fs->private->crawler,
 	                           fs->private->current_directory->file,
