@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, Nokia
+ * Copyright (C) 2009, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -87,6 +87,8 @@ writeback_xmp_content_types (TrackerWritebackFile *wbf)
 		"sketch/png",  /* .sketch.png files on Maemo*/
 		"image/jpeg",  /* .jpg & .jpeg files */
 		"image/tiff",  /* .tiff & .tif files */
+		"video/mp4",   /* .mp4 files */
+		"video/3gpp",  /* .3gpp files */
 		NULL
 	};
 
@@ -240,6 +242,8 @@ writeback_xmp_update_file_metadata (TrackerWritebackFile *wbf,
 		if (g_strcmp0 (row[2], TRACKER_NIE_PREFIX "contentCreated") == 0) {
 			xmp_delete_property (xmp, NS_EXIF, "Date");
 			xmp_set_property (xmp, NS_EXIF, "Date", row[3], 0);
+			xmp_delete_property (xmp,  NS_DC, "date");
+			xmp_set_property (xmp,  NS_DC, "date", row[3], 0);
 		}
 
 		if (g_strcmp0 (row[2], TRACKER_NFO_PREFIX "orientation") == 0) {
@@ -367,7 +371,7 @@ writeback_xmp_update_file_metadata (TrackerWritebackFile *wbf,
 		    g_strcmp0 (row[2], TRACKER_MLO_PREFIX "city") == 0     ||
 		    g_strcmp0 (row[2], TRACKER_MLO_PREFIX "country") == 0  ||
 		    g_strcmp0 (row[2], TRACKER_MLO_PREFIX "state") == 0    ||
-		    g_strcmp0 (row[2], TRACKER_MLO_PREFIX "address") == 0) 
+		    g_strcmp0 (row[2], TRACKER_MLO_PREFIX "address") == 0)
 		{
 			GPtrArray *array;
 			GError *error = NULL;
@@ -440,7 +444,7 @@ writeback_xmp_update_file_metadata (TrackerWritebackFile *wbf,
 		}
 
 		/* TODO: When a photo contains a known face
-		 * 
+		 *
 		 * if (g_strcmp0 (row[2], PHOTO_HAS "contact") == 0) {
 		  xmp_delete_property (xmp, FACE, "contact");
 		  Fetch full name of the contact?
